ingredients = [
    "apricot",
    "broccoli",
    "cherry",
    "date",
    "elderberry",
    "fig",
    "grape",
    "honeydew",
    "iceberg",
    "jalapeno",
    "kiwi",
    "lime",
    "mushroom",
    "nectarine",
    "olive",
    "pumpkin",
    "quince",
    "raspberry",
    "strawberry",
    "tangerine",
    "uglifruit",
    "vanilla",
    "watermelon",
    "xigua",
    "yam",
    "zucchini" "jamon",
    "melon",
]



import pytest

from ezpkl import load_txt, save_txt


def test_save_txt_string():
    data = "안뇽 세상!"
    save_txt(data, file_name="test_string")
    assert load_txt("test_string.txt") == data


def test_save_txt_list():
    data = ["apple", "banana", "cherry"]
    save_txt(data, file_name="test_list")
    assert load_txt("test_list.txt") == "\n".join(data)


def test_save_txt_invalid_filename():
    data = "춘의 쾌유를 빕니다"
    save_txt(data, file_name="test.txt")
    assert load_txt("test.txt") == data


def test_load_txt_nonexistent_file():
    filename = "nonexistent_file.txt"
    assert load_txt(filename) is None


def test_save_txt_no_filename_with_variable():
    data = "This is a test."
    save_txt(data)
    assert load_txt("data.txt") == data


def test_save_txt_with_separator():
    data = ["치유", "치유", "빔", "!", "✨"]
    save_txt(data, separator=None)
    assert load_txt("data.txt") == "치유치유빔!✨"



"""Make your life simply"""
import inspect
import random
from typing import Union

from ezpkl.refrigerator import ingredients


def save_txt(data, file_name: str = None, separator: str = "\n") -> None:
    """Saves data to a text file.

    Args:
        data: The data to be saved. Can be a string, list, or any other object that can be converted to a string.
        file_name: The name of the text file. If not provided, the function attempts to determine the variable name from the previous frame's local variables.
        separator: The separator to use between items in a list. Defaults to "\n", which means items will be joined with a newline character.

    Returns:
        None

    Raises:
        FileNotFoundError: If the file cannot be found.
        PermissionError: If there is a permission error while saving the file.
    """
    var_name = None
    frame = inspect.currentframe()
    try:
        if not file_name:
            previous_frame = frame.f_back
            for name, value in previous_frame.f_locals.items():
                if value is data:
                    var_name = name
                    break
            if var_name:
                file_name = f"{var_name}.txt"
            else:
                file_name = f"{random.choice(ingredients)}.txt"
                print("I couldn't find the variable name, but here's some ingredient for you instead!")
        elif not file_name.endswith(".txt"):
            file_name = f"{file_name}.txt"

        try:
            with open(file_name, "w") as file:
                if isinstance(data, list):
                    if separator is None:
                        file.write("".join(str(item) for item in data))
                    else:
                        file.write(separator.join(str(item) for item in data))
                else:
                    file.write(str(data))
            print(f"Data saved to '{file_name}'.")
        except (FileNotFoundError, PermissionError) as e:
            print(f"Error saving data: {str(e)}")
    finally:
        del frame


def load_txt(filename: str) -> Union[str, None]:
    """Loads data from a text file.

    Args:
        filename: The name of the text file.

    Returns:
        The data loaded from the file, or None if the file is not found.

    Raises:
        FileNotFoundError: If the file cannot be found.
    """
    try:
        with open(filename, "r") as file:
            return file.read()
    except FileNotFoundError:
        print(f"File '{filename}' not found.")
        return None



"""Easy peasy lemon squeezy!🍋🤝🍸"""
import inspect
import pickle
import random

from ezpkl.refrigerator import ingredients

# TODO: add filename, folder opt
def save_pkl(var, file_name: str = None) -> None:
    """Saves a variable as a pickle file.

    Args:
        var: The variable to be saved as a pickle file.
        file_name: The name of the pickle file. If not provided, the function attempts to determine the variable name from the previous frame's local variables.

    Returns:
        None

    Raises:
        FileNotFoundError: If the file cannot be found.
        PermissionError: If there is a permission error while saving the file.
    """
    var_name = None
    frame = inspect.currentframe()
    try:
        if not file_name:
            previous_frame = frame.f_back
            for name, value in previous_frame.f_locals.items():
                if value is var:
                    var_name = name
                    break
            if var_name:
                file_name = f"{var_name}.pkl"
            else:
                
                file_name = f"{random.choice(ingredients)}.pkl"
                print(
                    "I couldn't find the variable name, but here's some ingredient for you instead!"
                )
        elif not file_name.endswith(".pkl"):
            file_name = f"{file_name}.pkl"

        try:
            with open(file_name, "wb") as file:
                pickle.dump(var, file)
            print(f"Variable '{file_name}' saved.")
        except (FileNotFoundError, PermissionError) as e:
            print(f"Error saving variable: {str(e)}")
    finally:
        del frame


def load_pkl(filename: str):
    try:
        with open(filename, "rb") as file:
            return pickle.load(file)
    except FileNotFoundError:
        print(f"File '{filename}' not found.")
        return None



import pytest

from ezpkl import save_pkl, load_pkl

def test_save_pkl():
    data = [1, 2, 3, (4), 5]
    save_pkl(data)
    assert load_pkl("data.pkl") == data

def test_save_pkl_with_filename():
    data = [1, 2, 3, 4, 5]
    save_pkl(data, file_name="test_data")
    assert load_pkl("test_data.pkl") == data



from setuptools import find_packages, setup

with open("README.md", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="ezpkl",
    version='0.2.0',
    description="lovely pickling🥒 for context manager hater👊",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="bailando",
    author_email="bailando.ys@gmail.com",
    url="https://github.com/yesinkim/ezpkl.git",
    packages=find_packages(exclude=[]),
    keywords=["pickle", "file", "easy", "easypickle"],
    python_requires=">=3",
)
